@@ -1,10 +1,10 @@
 export const LINE_FEED = '\n'
 export const DECLARATION_TYPE_EXT = '.d.ts'
 export const JS_JSX_EXTENSIONS = ['.js', '.jsx']
-export const TS_TSX_REGEX = /\.tsx?$/
-export const JS_JSX_REGEX = /\.jsx?$/
-// `extensionsToTreatAsEsm` only accepts `.ts`, `.tsx` and `.jsx`. `.js`, `.cjs`, `.mjs` will throw error
-export const TS_EXT_TO_TREAT_AS_ESM = ['.ts', '.tsx']
+export const TS_TSX_REGEX = /\.m?tsx?$/
+export const JS_JSX_REGEX = /\.m?jsx?$/
+// `extensionsToTreatAsEsm` will throw error with `.mjs`
+export const TS_EXT_TO_TREAT_AS_ESM = ['.ts', '.tsx', '.mts']
 export const JS_EXT_TO_TREAT_AS_ESM = ['.jsx']
 /**
  * @internal
