@@ -17,7 +17,7 @@ declare module '@jest/types' {
        */
       // eslint-disable-next-line
       // @ts-ignore
-      'ts-jest': TsJestGlobalOptions
+      'ts-jest'?: TsJestGlobalOptions
     }
   }
 }
@@ -26,9 +26,15 @@ declare module '@jest/types' {
  * @internal
  */
 export type TBabelCore = typeof _babel
+/**
+ * @internal
+ */
 export type TBabelJest = typeof babelJest
 export type TTypeScript = typeof _ts
 // Stimulate `esbuild` type to avoid import `esbuild` while building the assets which are shipped to npm
+/**
+ * @internal
+ */
 export interface TEsBuild {
   transformSync(
     input: string,
@@ -46,11 +52,6 @@ export type BabelJestTransformer = {
  */
 export type BabelConfig = _babel.TransformOptions
 
-export type TsJestPresets = Pick<
-  Config.InitialOptions,
-  'extensionsToTreatAsEsm' | 'moduleFileExtensions' | 'transform' | 'testMatch'
->
-
 export interface AstTransformer<T = Record<string, unknown>> {
   path: string
   options?: T
@@ -62,6 +63,9 @@ export interface ConfigCustomTransformer {
   afterDeclarations?: Array<string | AstTransformer>
 }
 
+/**
+ * @deprecated use `TsJestTransformerOptions` instead
+ */
 export interface TsJestGlobalOptions {
   /**
    * Compiler options. It can be:
@@ -156,67 +160,52 @@ export interface TsJestGlobalOptions {
   useESM?: boolean
 }
 
-interface TsJestConfig$tsConfig$file {
-  kind: 'file'
-  value: string | undefined
-}
-interface TsJestConfig$tsConfig$inline {
-  kind: 'inline'
-  value: _ts.CompilerOptions
-}
-type TsJestConfig$tsConfig = TsJestConfig$tsConfig$file | TsJestConfig$tsConfig$inline | undefined
-export interface TsJestDiagnosticsCfg {
-  pretty: boolean
-  ignoreCodes: number[]
-  exclude: string[]
-  throws: boolean
-  warnOnly?: boolean
-}
-interface TsJestConfig$babelConfig$file {
-  kind: 'file'
-  value: string | undefined
-}
-interface TsJestConfig$babelConfig$inline {
-  kind: 'inline'
-  value: BabelConfig
-}
-type TsJestConfig$babelConfig = TsJestConfig$babelConfig$file | TsJestConfig$babelConfig$inline | undefined
-/**
- * @internal
- */
-export interface TsJestConfig {
-  tsconfig: TsJestConfig$tsConfig
-  isolatedModules: boolean
-  compiler: string
-  diagnostics: TsJestDiagnosticsCfg
-  babelConfig: TsJestConfig$babelConfig
-  transformers: ConfigCustomTransformer
-  // to deprecate / deprecated === === ===
-  stringifyContentPathRegex: string | undefined
-}
-
 /**
  * For transformers which extends `ts-jest`
+ * @deprecated use `JestConfigWithTsJest` instead
  */
 export interface ProjectConfigTsJest extends Config.ProjectConfig {
   globals: GlobalConfigTsJest
 }
+/**
+ * @deprecated use `JestConfigWithTsJest` instead
+ */
 export interface TransformOptionsTsJest extends TransformOptions {
   config: ProjectConfigTsJest
 }
 
 /**
  * For typings in `jest.config.ts`
+ * @deprecated use `JestConfigWithTsJest` instead
  */
 export interface GlobalConfigTsJest extends Config.ConfigGlobals {
-  'ts-jest': TsJestGlobalOptions
+  'ts-jest'?: TsJestGlobalOptions
 }
+/**
+ * @deprecated use `JestConfigWithTsJest` instead
+ */
 export interface InitialOptionsTsJest extends Config.InitialOptions {
   globals?: GlobalConfigTsJest
 }
+export type TsJestTransformerOptions = TsJestGlobalOptions
+export interface JestConfigWithTsJest extends Omit<Config.InitialOptions, 'transform'> {
+  transform?: {
+    [regex: string]:
+      | 'ts-jest'
+      | 'ts-jest/legacy'
+      | ['ts-jest', TsJestTransformerOptions]
+      | ['ts-jest/legacy', TsJestTransformerOptions]
+      | string
+      | Config.TransformerConfig
+  }
+}
+
+export type TsJestPresets = Pick<
+  JestConfigWithTsJest,
+  'extensionsToTreatAsEsm' | 'moduleFileExtensions' | 'transform' | 'testMatch'
+>
 
 export type StringMap = Map<string, string>
-
 export interface DepGraphInfo {
   fileContent: string
   resolvedModuleNames: string[]
